@@ -27,6 +27,7 @@
 #include <QtCore/QTranslator>
 #include <QtCore/QLocale>
 #include <QtCore/QLibraryInfo>
+#include <QtCore/QDir>
 #include <QtGui/QApplication>
 
 //////////////////////////////////////////////////////////////////////////
@@ -45,10 +46,22 @@ int main(int argc, char *argv[])
   if ( qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)) )
     app.installTranslator(&qtTranslator);
 
-  // Load a new translation for web2sms
-  QTranslator translator;
-  if ( translator.load( QString("web2sms_%1").arg(QLocale::system().name()), ":/translations" ) )
-    app.installTranslator(&translator);
+  // Load translations
+  QDir dir( app.applicationDirPath() );
+  if ( dir.cd("translations") )
+  {
+    QStringList nameFilters;
+    nameFilters << QString("*_%1*").arg(QLocale::system().name().left(2));
+
+    foreach(const QFileInfo& fileInfo, dir.entryInfoList(nameFilters, QDir::Files))
+    {
+      QTranslator* translator = new QTranslator(&app);
+      if ( translator->load(fileInfo.baseName(), dir.absolutePath()) )
+        app.installTranslator(translator);
+      else
+        delete translator;
+    }
+  }
 
   // Init the contacts api
   init_contacts();
