@@ -22,6 +22,7 @@
 // Local includes
 #include "mainwindow.hpp"
 #include "messagewidget.hpp"
+#include "startwidget.hpp"
 #include "providers/providerinterface.hpp"
 #include "providers/accountsdialog.hpp"
 #include "providers/accounts.hpp"
@@ -43,12 +44,14 @@ class MainWindowPrivate : public QObject
 public:
   MainWindowPrivate()
   : accounts(new Accounts)
+  , messageWidget(NULL)
   {}
 
   MainWindow* self;
 
   // Properties
   AccountsPtr accounts;
+  StartWidget* startWidget;
   MessageWidget* messageWidget;
 
   // Functions
@@ -60,6 +63,7 @@ public:
 public slots:
   // Ui callbacks
   void onEditAccounts();
+  void onAliasClicked(const QString& alias);
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -71,11 +75,15 @@ void MainWindowPrivate::init()
   accounts->loadPlugins();
   accounts->loadSettings();
 
-  messageWidget = new MessageWidget(self);
-  messageWidget->setAccounts(accounts);
+  startWidget = new StartWidget(self);
+  startWidget->setAccounts(accounts);
+
+#ifdef Q_WS_MAEMO_5
+  self->setAttribute(Qt::WA_Maemo5StackedWindow);
+#endif // Q_WS_MAEMO_5
 
   // Set the message widget as central widget
-  self->setCentralWidget(messageWidget);
+  self->setCentralWidget(startWidget);
 
   // Setup the menu
   QMenu* menu = self->menuBar()->addMenu(QString());
@@ -85,6 +93,9 @@ void MainWindowPrivate::init()
   // We have to set a window title, otherwise Windows won't show the menu
   menu->setTitle("menu");
 #endif
+
+  // Make the connections
+  connect(startWidget, SIGNAL(accountClicked(QString)), this, SLOT(onAliasClicked(QString)));
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -102,6 +113,33 @@ void MainWindowPrivate::onEditAccounts()
   accounts->saveSettings();
 }
 
+//////////////////////////////////////////////////////////////////////////
+
+void MainWindowPrivate::onAliasClicked(const QString& alias)
+{
+  // Find the provider interface
+  ProviderInterface* provider = accounts->providerForAlias(alias);
+
+  if ( !messageWidget )
+  {
+    messageWidget = new MessageWidget(self, Qt::Window);
+
+#ifdef Q_WS_MAEMO_5
+    messageWidget->setAttribute(Qt::WA_Maemo5StackedWindow);
+#endif // Q_WS_MAEMO_5
+  }
+
+  // Make the message view prettier
+  ProviderInfo info = accounts->providerInfoForAlias(alias);
+  messageWidget->setWindowTitle( tr("Send SMS with %1").arg(info.visibleName()) );
+
+  // Show the message widget
+  messageWidget->show();
+
+  // Set the provider to the message widget
+  messageWidget->setProvider(provider);
+}
+
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -132,26 +170,30 @@ void MainWindow::init()
 void MainWindow::closeEvent(QCloseEvent* closeEvent)
 {
   // Logout first?
-  ProviderInterface* provider = d->messageWidget->provider();
+  ProviderInterface* provider = d->messageWidget ? d->messageWidget->provider() : NULL;
 
   if ( provider && provider->isLoggedIn() )
   {
-    // Ignore the close event
-    closeEvent->ignore();
+    CallbackType cb = provider->logout();
+    if ( cb == Callback_Sync )
+      QWidget::closeEvent(closeEvent);
+    else
+    {
+      // Ignore the close event
+      closeEvent->ignore();
 
-    // Show a dialog that we're logging out first
-    QProgressDialog* progressDialog = new QProgressDialog(this);
-    progressDialog->setAttribute(Qt::WA_DeleteOnClose);
-    progressDialog->setWindowTitle( tr("Logging out ...") );
-    progressDialog->setRange(0, 0);
-    progressDialog->show();
+      // Show a dialog that we're logging out first
+      QProgressDialog* progressDialog = new QProgressDialog(this);
+      progressDialog->setAttribute(Qt::WA_DeleteOnClose);
+      progressDialog->setWindowTitle( tr("Logging out ...") );
+      progressDialog->setRange(0, 0);
 
-    // Close the information dialog and this window
-    connect(provider, SIGNAL(logoutReply(bool)), progressDialog, SLOT(accept()));
-    connect(provider, SIGNAL(logoutReply(bool)), this, SLOT(close()));
+      // Close the information dialog and this window
+      connect(provider, SIGNAL(logoutReply(bool)), progressDialog, SLOT(accept()));
+      connect(provider, SIGNAL(logoutReply(bool)), this, SLOT(close()));
 
-    // Log out now
-    provider->logout();
+      progressDialog->show();
+    }
   }
   else
   {
