@@ -103,20 +103,26 @@ void MessageWidgetPrivate::init()
 
 void MessageWidgetPrivate::updateUi()
 {
-  // Calculate message information
-  MessageType messageType = qvariant_cast<MessageType>(messageTypeModel.index(ui.messageTypePicker->currentIndex()).data(MessageTypeModel::MessageTypeRole));
-  int completeCharacterCount = ui.messageText->toPlainText().size(); // EEEK, this could be done faster!
-  int messageCharacterCount = completeCharacterCount % messageType.singleMessageLength();
+  QVariant messageTypeData = messageTypeModel.index(ui.messageTypePicker->currentIndex()).data(MessageTypeModel::MessageTypeRole);
+  if ( messageTypeData.userType() == qMetaTypeId<MessageType>() )
+  {
+    // Calculate message information
+    MessageType messageType = qvariant_cast<MessageType>(messageTypeData);
+    int completeCharacterCount = ui.messageText->toPlainText().size(); // EEEK, this could be done faster!
+    int messageCharacterCount = completeCharacterCount % messageType.singleMessageLength();
 
-  // Fixup lengths
-  if ( messageCharacterCount == 0 )
-    messageCharacterCount = messageType.singleMessageLength();
+    // Fixup lengths
+    if ( messageCharacterCount == 0 )
+      messageCharacterCount = messageType.singleMessageLength();
 
-  int remainingCharacters = messageType.singleMessageLength() - messageCharacterCount;
-  int messageCount = ((float)completeCharacterCount / (float)messageType.singleMessageLength()) + 0.999f; // Ehem, also not the best solution
+    int remainingCharacters = messageType.singleMessageLength() - messageCharacterCount;
+    int messageCount = completeCharacterCount == 0 ? 1 : ((float)completeCharacterCount / (float)messageType.singleMessageLength()) + 0.999f; // Ehem, also not the best solution
 
-  // Update the message information
-  ui.messageInfoLabel->setText( QString("%1 (%2)").arg(remainingCharacters).arg(messageCount) );
+    // Update the message information
+    ui.messageInfoLabel->setText( QString("%1 (%2)").arg(remainingCharacters).arg(messageCount) );
+  }
+  else
+    ui.messageInfoLabel->setText( QString() );
 
   // Update the send button state
   bool enableSendButton = false;
