@@ -24,6 +24,7 @@
 
 // Local includes
 #include "providerinterface.hpp"
+#include "providerinfo.hpp"
 
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -35,7 +36,7 @@ struct ProviderPlugin
 
   // Functions?
   virtual QList<ProviderInfo> info() const = 0;
-  virtual ProviderInterface* createProvider(const QString& name) const = 0;
+  virtual ProviderInterface* createProvider(const QUuid& providerId) const = 0;
 };
 
 Q_DECLARE_INTERFACE(ProviderPlugin, "org.maemo.garage.web2sms.ProviderPlugin/1.0");
